@@ -4,7 +4,7 @@ import pandas as pd
 from bs4 import BeautifulSoup
 
 
-def parse_rowspan_table(table):
+def parse_rowspan_table(table: str) -> pd.DataFrame:
     """
     based on http://stackoverflow.com/a/28766684
     """
@@ -15,11 +15,9 @@ def parse_rowspan_table(table):
     allRows = tmp[1:-1]
 
     headers = [header.get_text() for header in first.find_all("th")]
-
     results = [[data.get_text() for data in row.find_all("td")] for row in allRows]
 
     rowspan = []
-
     for no, tr in enumerate(allRows):
         for td_no, data in enumerate(tr.find_all("td")):
             if data.has_attr("rowspan"):
@@ -31,16 +29,14 @@ def parse_rowspan_table(table):
             for j in range(1, i[2]):
                 # Add value in next tr.
                 results[i[0] + j].insert(i[1], i[3])
-
     return pd.DataFrame(data=results, columns=headers)
 
 
-def ciaaw_atomic_masses():
+def ciaaw_atomic_masses() -> pd.DataFrame:
     """
     Scrape the CIAAW webpage for atomic masses and return them as
-    pandas DataFrame
+    pandas DataFrame.
     """
-
     url = "http://ciaaw.org/atomic-masses.htm"
 
     req = urllib.request.Request(url)
@@ -58,7 +54,7 @@ def ciaaw_atomic_masses():
     df.loc[:, "is_radioactive"] = df["A"].str.contains("*", regex=False)
     df.loc[:, "A"] = df["A"].str.extract("([0-9]+)", expand=False).astype(int)
 
-    df.loc[:, "AM wows"] = df["Atomic mass,ma/Da"].str.replace("\s", "")
+    df.loc[:, "AM wows"] = df["Atomic mass,ma/Da"].str.replace(r"\s", "")
     df[["AM lead", "AM decimals", "AM unc"]] = df["AM wows"].str.extract(
         r"(\d+)\.(\d+)\((\d+)\)", expand=True
     )
@@ -85,12 +81,11 @@ def ciaaw_atomic_masses():
     return df
 
 
-def ciaaw_atomic_weights():
+def ciaaw_atomic_weights() -> pd.DataFrame:
     """
     Scrape the CIAAW webpage for atomic weights and return them as
-    pandas DataFrame
+    pandas DataFrame.
     """
-
     url = "http://ciaaw.org/atomic-weights.htm"
 
     table = pd.read_html(url, attrs={"id": "mytable"})[0]
@@ -99,7 +94,7 @@ def ciaaw_atomic_weights():
 
     table = table.rename(columns={"Standard Atomic Weight": "SAW"})
     table.loc[:, "Z"] = table["Z"].astype(int)
-    table.loc[:, "SAW"] = table["SAW"].str.replace("\s", "")
+    table.loc[:, "SAW"] = table["SAW"].str.replace(r"\s", "")
     table[["SAW decimals", "SAW unc"]] = table["SAW"].str.extract(
         r"\d+\.(\d+)\((\d+)\)", expand=True
     )
@@ -119,7 +114,7 @@ def ciaaw_atomic_weights():
     return table
 
 
-def ciaaw_isotopic_abundances():
+def ciaaw_isotopic_abundances() -> pd.DataFrame:
 
     url = "http://ciaaw.org/isotopic-abundances.htm"
 
@@ -133,7 +128,7 @@ def ciaaw_isotopic_abundances():
     abu = "Representative isotopic composition"
     ia.loc[:, "A"] = ia["A"].str.extract("([0-9]+)", expand=False).astype(int)
     ia.loc[:, "Z"] = ia["Z"].astype(int)
-    ia.loc[:, abu] = ia[abu].str.replace("\s", "")
+    ia.loc[:, abu] = ia[abu].str.replace(r"\s", "")
     ia.loc[:, "abundance"] = ia[abu].str.extract(r"(\d+\.\d+)\(", expand=False)
     ia.loc[:, "abundance"].fillna(
         ia[abu].str.extract(r"\[(\d+\.\d+),", expand=False), inplace=True
@@ -142,12 +137,11 @@ def ciaaw_isotopic_abundances():
     return ia
 
 
-def ciaaw_monoisotopic():
+def ciaaw_monoisotopic() -> pd.DataFrame:
     """
     Scrape the CIAAW webpage for monoisotopic elements and return the
     data as pandas DataFrame
     """
-
     url = "http://ciaaw.org/monoisotopic-elements.htm"
 
     # parse monoisotopic elements
