@@ -5,12 +5,13 @@ from __future__ import print_function
 import argparse
 import textwrap
 import colorama
+import contextlib
 from pyfiglet import Figlet
 from mendeleev import element
 from mendeleev.fetch import fetch_table
 
 
-def clielement():
+def clielement() -> None:
     """
     CLI for convenient printing of properties for a given element
     """
@@ -23,11 +24,8 @@ def clielement():
     )
     args = parser.parse_args()
 
-    try:
+    with contextlib.suppress(ValueError):
         args.element = int(args.element)
-    except ValueError:
-        pass
-
     e = element(args.element)
 
     f = Figlet("dotmatrix", justify="center")
@@ -43,25 +41,23 @@ def clielement():
     et.sort_index(inplace=True)
 
     # print the data
-
     print(colorama.Fore.RED + symbol)
 
     if e.description is not None:
         print(colorama.Fore.BLUE + "Description\n===========\n")
-        print("\n".join("  " + s for s in textwrap.wrap(e.description, 70)))
+        print("\n".join(f"  {s}" for s in textwrap.wrap(e.description, 70)))
 
     if e.sources is not None:
         print(colorama.Fore.BLUE + "\nSources\n=======\n")
-        print("\n".join("  " + s for s in textwrap.wrap(e.sources, 70)))
+        print("\n".join(f"  {s}" for s in textwrap.wrap(e.sources, 70)))
 
     if e.uses is not None:
         print(colorama.Fore.BLUE + "\nUses\n====\n")
-        print("\n".join("  " + s for s in textwrap.wrap(e.uses, 70)))
+        print("\n".join(f"  {s}" for s in textwrap.wrap(e.uses, 70)))
 
     print(colorama.Fore.GREEN + "\nProperties\n==========\n")
     print(et.to_string(justify="left", header=False))
 
 
 if __name__ == "__main__":
-
     clielement()
